@@ -1,3 +1,3 @@
-'''Run alidistlint as a script.'''
+"""Run alidistlint as a script."""
 from alidistlint.run import main
 main()
